@@ -8,7 +8,7 @@
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy 
+  by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.
 
   This program is distributed in the hope that it will be useful,
@@ -28,7 +28,7 @@
 HeaderViewMenuHandler::HeaderViewMenuHandler(QHeaderView* headerView): QObject(headerView)
 {
     headerView->setContextMenuPolicy(Qt::CustomContextMenu);
-    connect(headerView, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(headerMenuRequested(QPoint)));
+    connect(headerView, &QHeaderView::customContextMenuRequested, this, &HeaderViewMenuHandler::headerMenuRequested);
 }
 
 void HeaderViewMenuHandler::headerMenuRequested(QPoint pos)
@@ -36,11 +36,10 @@ void HeaderViewMenuHandler::headerMenuRequested(QPoint pos)
     QHeaderView* headerView = static_cast<QHeaderView*>(parent());
     bool allowHiding = (headerView->count() - headerView->hiddenSectionCount()) > 1;
     QMenu* headerMenu = new QMenu(headerView);
-    connect(headerMenu, SIGNAL(aboutToHide()), headerMenu, SLOT(deleteLater()), Qt::QueuedConnection);
-    connect(headerMenu, SIGNAL(triggered(QAction*)), this, SLOT(headerMenuActionToggled(QAction*)));
-    for (int i=0;i<headerView->count();++i)
-    {
-        QAction* a=headerMenu->addAction(headerView->model()->headerData(i,Qt::Horizontal,Qt::DisplayRole).toString());
+    connect(headerMenu, &QMenu::aboutToHide, headerMenu, &QMenu::deleteLater, Qt::QueuedConnection);
+    connect(headerMenu, &QMenu::triggered, this, &HeaderViewMenuHandler::headerMenuActionToggled);
+    for (int i = 0; i < headerView->count(); ++i) {
+        QAction* a = headerMenu->addAction(headerView->model()->headerData(i, Qt::Horizontal, Qt::DisplayRole).toString());
         a->setData(i);
         a->setCheckable(true);
         a->setChecked(!headerView->isSectionHidden(i));
