@@ -23,11 +23,8 @@
 
 #include "languagelistmodel.h"
 
-#ifndef NOKDE
-//#include <kiconloader.h>
 #include <kconfig.h>
 #include <kconfiggroup.h>
-#endif
 
 #include <QStringBuilder>
 #include <QCoreApplication>
@@ -39,8 +36,8 @@
 
 
 
-LanguageListModel* LanguageListModel::_instance=0;
-LanguageListModel* LanguageListModel::_emptyLangInstance=0;
+LanguageListModel* LanguageListModel::_instance = 0;
+LanguageListModel* LanguageListModel::_emptyLangInstance = 0;
 void LanguageListModel::cleanupLanguageListModel()
 {
     delete LanguageListModel::_instance; LanguageListModel::_instance = 0;
@@ -49,9 +46,8 @@ void LanguageListModel::cleanupLanguageListModel()
 
 LanguageListModel* LanguageListModel::instance()
 {
-    if (_instance==0 )
-    {
-        _instance=new LanguageListModel();
+    if (_instance == 0) {
+        _instance = new LanguageListModel();
         qAddPostRoutine(LanguageListModel::cleanupLanguageListModel);
     }
     return _instance;
@@ -59,30 +55,19 @@ LanguageListModel* LanguageListModel::instance()
 
 LanguageListModel* LanguageListModel::emptyLangInstance()
 {
-    if (_emptyLangInstance==0 )
-        _emptyLangInstance=new LanguageListModel(WithEmptyLang);
+    if (_emptyLangInstance == 0)
+        _emptyLangInstance = new LanguageListModel(WithEmptyLang);
     return _emptyLangInstance;
 }
 
 LanguageListModel::LanguageListModel(ModelType type, QObject* parent)
- : QStringListModel(parent)
- , m_sortModel(new QSortFilterProxyModel(this))
-#ifndef NOKDE
- , m_systemLangList(new KConfig(QLatin1String("locale/kf5_all_languages"), KConfig::NoGlobals, QStandardPaths::GenericDataLocation))
-#endif
+    : QStringListModel(parent)
+    , m_sortModel(new QSortFilterProxyModel(this))
+    , m_systemLangList(new KConfig(QLatin1String("locale/kf5_all_languages"), KConfig::NoGlobals, QStandardPaths::GenericDataLocation))
 {
-#ifndef NOKDE
     setStringList(m_systemLangList->groupList());
-#else
-    QStringList ll;
-    QList<QLocale> allLocales = QLocale::matchingLocales(QLocale::AnyLanguage, QLocale::AnyScript, QLocale::AnyCountry);
-    foreach(const QLocale& l, allLocales)
-        ll.append(l.name());
-    ll=ll.toSet().toList();
-    setStringList(ll);
-#endif
 
-    if (type==WithEmptyLang) insertRows(rowCount(), 1);
+    if (type == WithEmptyLang) insertRows(rowCount(), 1);
 #if 0 //KDE5PORT
     KIconLoader::global()->addExtraDesktopThemes();
 #endif
@@ -94,44 +79,32 @@ LanguageListModel::LanguageListModel(ModelType type, QObject* parent)
 
 QVariant LanguageListModel::data(const QModelIndex& index, int role) const
 {
-    if (role==Qt::DecorationRole)
-    {
-#if 0 //#ifndef NOKDE
-        static QMap<QString,QVariant> iconCache;
+    if (role == Qt::DecorationRole) {
+#if 0 //#
+        static QMap<QString, QVariant> iconCache;
 
-        QString langCode=stringList().at(index.row());
-        if (!iconCache.contains(langCode))
-        {
-            QString code=QLocale(langCode).name();
+        QString langCode = stringList().at(index.row());
+        if (!iconCache.contains(langCode)) {
+            QString code = QLocale(langCode).name();
             QString path;
-            if (code.contains('_')) code=QString::fromRawData(code.unicode()+3, 2).toLower();
-            if (code!="C")
-            {
+            if (code.contains('_')) code = QString::fromRawData(code.unicode() + 3, 2).toLower();
+            if (code != "C") {
                 static const QString flagPath("l10n/%1/flag.png");
-                path=QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("locale/") + flagPath.arg(code));
+                path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("locale/") + flagPath.arg(code));
             }
-            iconCache[langCode]=QIcon(path);
+            iconCache[langCode] = QIcon(path);
         }
         return iconCache.value(langCode);
 #endif
-    }
-    else if (role==Qt::DisplayRole)
-    {
-        const QString& code=stringList().at(index.row());
+    } else if (role == Qt::DisplayRole) {
+        const QString& code = stringList().at(index.row());
         if (code.isEmpty()) return code;
         //qCDebug(LOKALIZE_LOG)<<"languageCodeToName"<<code;
         static QVector<QString> displayNames(stringList().size());
         if (displayNames.at(index.row()).length())
             return displayNames.at(index.row());
-#ifndef NOKDE
-            return QVariant::fromValue<QString>(
-                displayNames[index.row()]=KConfigGroup(m_systemLangList,code).readEntry("Name")%QStringLiteral(" (")%code%')');
-#else
-        QLocale l(code);
-//        if (l.language()==QLocale::C && code!="C")
         return QVariant::fromValue<QString>(
-            displayNames[index.row()]=QLocale::languageToString(l.language())%QStringLiteral(" (")%code%')');
-#endif
+                   displayNames[index.row()] = KConfigGroup(m_systemLangList, code).readEntry("Name") % QStringLiteral(" (") % code % ')');
     }
     return QStringListModel::data(index, role);
 }
@@ -148,7 +121,7 @@ int LanguageListModel::sortModelRowForLangCode(const QString& langCode)
 
 QString LanguageListModel::langCodeForSortModelRow(int row)
 {
-    return stringList().at(m_sortModel->mapToSource(m_sortModel->index(row,0)).row());
+    return stringList().at(m_sortModel->mapToSource(m_sortModel->index(row, 0)).row());
 }
 
 
@@ -163,8 +136,7 @@ QString LanguageListModel::langCodeForSortModelRow(int row)
 
 QString getTargetLangCode(const QString& title, bool askUser)
 {
-    if (!askUser)
-    {
+    if (!askUser) {
         if (Project::instance()->targetLangCode().length())
             return Project::instance()->targetLangCode();
         return QLocale::system().name();
@@ -172,16 +144,16 @@ QString getTargetLangCode(const QString& title, bool askUser)
 
     QDialog dlg(SettingsController::instance()->mainWindowPtr());
     dlg.setWindowTitle(title);
-    QHBoxLayout* l=new QHBoxLayout(&dlg);
+    QHBoxLayout* l = new QHBoxLayout(&dlg);
     l->addWidget(new QLabel(i18n("Target language:"), &dlg));
-    QComboBox* lc=new QComboBox(&dlg);
+    QComboBox* lc = new QComboBox(&dlg);
     l->addWidget(lc);
     lc->setModel(LanguageListModel::instance()->sortModel());
-    lc->setCurrentIndex(LanguageListModel::instance()->sortModelRowForLangCode( Project::instance()->targetLangCode() ));
-    QDialogButtonBox* btn=new QDialogButtonBox(QDialogButtonBox::Ok, &dlg);
+    lc->setCurrentIndex(LanguageListModel::instance()->sortModelRowForLangCode(Project::instance()->targetLangCode()));
+    QDialogButtonBox* btn = new QDialogButtonBox(QDialogButtonBox::Ok, &dlg);
     l->addWidget(btn);
-    QObject::connect(btn, SIGNAL(accepted()), &dlg, SLOT(accept()));
-    QObject::connect(btn, SIGNAL(rejected()), &dlg, SLOT(reject()));
+    QObject::connect(btn, &QDialogButtonBox::accepted, &dlg, &QDialog::accept);
+    QObject::connect(btn, &QDialogButtonBox::rejected, &dlg, &QDialog::reject);
 
     dlg.show();
     dlg.activateWindow(); //if we're called from another app
