@@ -32,17 +32,22 @@
 #include "lokalizesubwindowbase.h"
 
 #include <QHash>
+#include <KProcess>
 
-#ifndef NOKDE
-namespace Sonnet{class Dialog;}
-namespace Sonnet{class BackgroundChecker;}
+namespace Sonnet
+{
+class Dialog;
+}
+namespace Sonnet
+{
+class BackgroundChecker;
+}
 
 #include <kxmlguiclient.h>
 
 class KFind;
 class KReplace;
 class KActionCategory;
-#endif
 
 class Project;
 class Catalog;
@@ -51,16 +56,18 @@ class MergeView;
 class CatalogView;
 class MsgCtxtView;
 class AltTransView;
-namespace GlossaryNS{class GlossaryView;}
-
-
-
-struct EditorState
+namespace GlossaryNS
 {
+class GlossaryView;
+}
+
+
+
+struct EditorState {
 public:
-    EditorState(): entry(0){}
-    EditorState(const EditorState& s):dockWidgets(s.dockWidgets), filePath(s.filePath), entry(0) {}
-    ~EditorState(){}
+    EditorState(): entry(0) {}
+    EditorState(const EditorState& s): dockWidgets(s.dockWidgets), filePath(s.filePath), entry(0) {}
+    ~EditorState() {}
 
     QByteArray dockWidgets;
     QString filePath;
@@ -88,44 +95,70 @@ class EditorTab: public LokalizeSubwindowBase2
 #define qdbuscpp2xml
 
 public:
-    EditorTab(QWidget* parent, bool valid=true);
-    ~EditorTab();
+    explicit EditorTab(QWidget* parent, bool valid = true);
+    ~EditorTab() override;
 
 
     //interface for LokalizeMainWindow
-    void hideDocks();
-    void showDocks();
-    QString currentFilePath();
+    void hideDocks() override;
+    void showDocks() override;
+    QString currentFilePath() override;
     void setFullPathShown(bool);
-    void setProperCaption(QString,bool);//reimpl to remove ' - Lokalize'
+    void setProperCaption(QString, bool); //reimpl to remove ' - Lokalize'
 public slots:
     void setProperFocus();
 public:
-    bool queryClose();
+    bool queryClose() override;
     EditorState state();
-#ifndef NOKDE
-    KXMLGUIClient* guiClient(){return (KXMLGUIClient*)this;}
+    KXMLGUIClient* guiClient() override
+    {
+        return (KXMLGUIClient*)this;
+    }
     QString dbusObjectPath();
-    int dbusId(){return m_dbusId;}
-    QObject* adaptor(){return m_adaptor;}
-#endif
+    int dbusId()
+    {
+        return m_dbusId;
+    }
+    QObject* adaptor()
+    {
+        return m_adaptor;
+    }
 
     //wrapper for cmdline handling
     void mergeOpen(QString mergeFilePath);
 
-    bool fileOpen(QString filePath=QString(), QString suggestedDirPath=QString(), bool silent=false);
+    bool fileOpen(QString filePath = QString(), QString suggestedDirPath = QString(), bool silent = false);
 public slots:
     //for undo/redo, views
-    void gotoEntry(DocPosition pos,int selection=0);
+    void gotoEntry(DocPosition pos);
+    void gotoEntry(DocPosition pos, int selection);
 #ifdef qdbuscpp2xml
-    Q_SCRIPTABLE void gotoEntry(int entry){gotoEntry(DocPosition(entry));}
-    Q_SCRIPTABLE void gotoEntryForm(int entry,int form){gotoEntry(DocPosition(entry,form));}
-    Q_SCRIPTABLE void gotoEntryFormOffset(int entry,int form, int offset){gotoEntry(DocPosition(entry,form,offset));}
-    Q_SCRIPTABLE void gotoEntryFormOffsetSelection(int entry,int form, int offset, int selection){gotoEntry(DocPosition(entry,form,offset),selection);}
+    Q_SCRIPTABLE void gotoEntry(int entry)
+    {
+        gotoEntry(DocPosition(entry));
+    }
+    Q_SCRIPTABLE void gotoEntryForm(int entry, int form)
+    {
+        gotoEntry(DocPosition(entry, form));
+    }
+    Q_SCRIPTABLE void gotoEntryFormOffset(int entry, int form, int offset)
+    {
+        gotoEntry(DocPosition(entry, form, offset));
+    }
+    Q_SCRIPTABLE void gotoEntryFormOffsetSelection(int entry, int form, int offset, int selection)
+    {
+        gotoEntry(DocPosition(entry, form, offset), selection);
+    }
 
     Q_SCRIPTABLE QString currentEntryId();
-    Q_SCRIPTABLE int currentEntry(){return m_currentPos.entry;}
-    Q_SCRIPTABLE int currentForm(){return m_currentPos.form;}
+    Q_SCRIPTABLE int currentEntry()
+    {
+        return m_currentPos.entry;
+    }
+    Q_SCRIPTABLE int currentForm()
+    {
+        return m_currentPos.form;
+    }
     Q_SCRIPTABLE QString selectionInTarget();
     Q_SCRIPTABLE QString selectionInSource();
 
@@ -144,18 +177,27 @@ public slots:
     Q_SCRIPTABLE void addAlternateTranslation(int entry, const QString& translation);
     Q_SCRIPTABLE void addTemporaryAlternateTranslation(int entry, const QString& translation);
 
-    Q_SCRIPTABLE QString currentFile(){return currentFilePath();}
+    Q_SCRIPTABLE QString currentFile()
+    {
+        return currentFilePath();
+    }
     Q_SCRIPTABLE QByteArray currentFileContents();
     Q_SCRIPTABLE QString sourceLangCode();
     Q_SCRIPTABLE QString targetLangCode();
 
     Q_SCRIPTABLE void attachAlternateTranslationFile(const QString& path);
-    Q_SCRIPTABLE void openSyncSource(QString path){mergeOpen(path);}
+    Q_SCRIPTABLE void openSyncSource(QString path)
+    {
+        mergeOpen(path);
+    }
     Q_SCRIPTABLE void reloadFile();
 #endif
-    Q_SCRIPTABLE bool saveFile(const QString& filePath=QString());
-    Q_SCRIPTABLE bool saveFileAs();
-    Q_SCRIPTABLE void close(){return parent()->deleteLater();}
+    Q_SCRIPTABLE bool saveFile(const QString& filePath = QString());
+    Q_SCRIPTABLE bool saveFileAs(const QString& defaultPath = QString());
+    Q_SCRIPTABLE void close()
+    {
+        return parent()->deleteLater();
+    }
     Q_SCRIPTABLE void gotoNextUnfiltered();
     Q_SCRIPTABLE void gotoPrevUnfiltered();
     Q_SCRIPTABLE void gotoFirstUnfiltered();
@@ -169,16 +211,18 @@ public slots:
 
     Q_SCRIPTABLE bool findEntryBySourceContext(const QString& source, const QString& ctxt);
 
-#ifndef NOKDE
-    Q_SCRIPTABLE bool isValid(){return m_valid;}
-    Q_SCRIPTABLE void setSrcFileOpenRequestAccepted(bool a){m_srcFileOpenRequestAccepted=a;}
-#endif
+    Q_SCRIPTABLE bool isValid()
+    {
+        return m_valid;
+    }
+    Q_SCRIPTABLE void setSrcFileOpenRequestAccepted(bool a)
+    {
+        m_srcFileOpenRequestAccepted = a;
+    }
 
 private slots:
-#ifndef NOKDE
-    void highlightFound(const QString &,int,int);//for find/replace
-    void highlightFound_(const QString &,int,int);//for find/replace
-#endif
+    void highlightFound(const QString &, int, int); //for find/replace
+    void highlightFound_(const QString &, int, int); //for find/replace
 
     void lookupSelectionInTranslationMemory();
 
@@ -196,16 +240,14 @@ private slots:
 
     void undo();
     void redo();
-#ifndef NOKDE
     void findNext();
     void findPrev();
     void find();
 
     void replace();
     void replaceNext();//internal
-    void doReplace(const QString&,int,int,int);//internal
+    void doReplace(const QString&, int, int, int); //internal
     void cleanupReplace();//internal
-#endif
 
 //     void selectAll();
 //     void deselectAll();
@@ -216,7 +258,8 @@ private slots:
     void gotoEntry();
 
     void gotoPrevFuzzyUntr();
-    bool gotoNextFuzzyUntr(const DocPosition& pos=DocPosition());
+    bool gotoNextFuzzyUntr(const DocPosition& pos);
+    bool gotoNextFuzzyUntr();
     void gotoNextFuzzy();
     void gotoPrevFuzzy();
     void gotoNextUntranslated();
@@ -226,19 +269,19 @@ private slots:
     void setApproveActionTitle();
 
 
-#ifndef NOKDE
     void spellcheck();
     void spellcheckNext();
-    void spellcheckShow(const QString&,int);
-    void spellcheckReplace(QString,int,const QString&);
+    void spellcheckShow(const QString&, int);
+    void spellcheckReplace(QString, int, const QString&);
     void spellcheckStop();
     void spellcheckCancel();
-#endif
 
     void gotoNextBookmark();
     void gotoPrevBookmark();
 
     void displayWordCount();
+    void clearTranslatedEntries();
+    void launchPology();
 
     void openPhasesWindow();
 
@@ -252,9 +295,11 @@ private slots:
 
     void fileAutoSaveFailedWarning(const QString&);
 
+    void pologyHasFinished(int exitCode, QProcess::ExitStatus exitStatus);
+
 protected:
-    void paintEvent(QPaintEvent* event);
-    
+    void paintEvent(QPaintEvent* event) override;
+
 private:
     void setupAccel();
     void setupActions();
@@ -270,7 +315,10 @@ private:
     EditorView* m_view;
     QAction* m_approveAndGoAction;
     QAction* m_approveAction;
-    QAction* m_stateAction; //is = m_approveAction ifndef NOKDE
+    QAction* m_stateAction;
+
+    KProcess* m_pologyProcess;
+    bool m_pologyProcessInProgress;
 
     DocPosition m_currentPos;
     DocPosition _searchingPos; //for find/replace
@@ -278,23 +326,19 @@ private:
     DocPosition _spellcheckPos;
     DocPosition _spellcheckStartPos;
 
-#ifndef NOKDE
     Sonnet::BackgroundChecker* m_sonnetChecker;
     Sonnet::Dialog* m_sonnetDialog;
     int m_spellcheckStartUndoIndex;
-    bool m_spellcheckStop:1;
-#endif
+    bool m_spellcheckStop: 1;
 
-    bool m_currentIsApproved:1; //for statusbar animation
-    bool m_currentIsUntr:1;  //for statusbar animation
+    bool m_currentIsApproved: 1; //for statusbar animation
+    bool m_currentIsUntr: 1; //for statusbar animation
 
-    bool m_fullPathShown:1;
+    bool m_fullPathShown: 1;
 
-#ifndef NOKDE
-    bool m_doReplaceCalled:1;//used to prevent non-clean catalog status
+    bool m_doReplaceCalled: 1; //used to prevent non-clean catalog status
     KFind* m_find;
     KReplace* m_replace;
-#endif
 
     //BEGIN views
     MergeView* m_syncView;
@@ -310,12 +354,10 @@ private:
     bool m_srcFileOpenRequestAccepted;
 
     //BEGIN dbus
-#ifndef NOKDE
     bool m_valid;
     QObject* m_adaptor;
     int m_dbusId;
     static QList<int> ids;
-#endif
     //END dbus
 
 signals:
@@ -324,7 +366,7 @@ signals:
 
     Q_SCRIPTABLE void srcFileOpenRequested(const QString& srcPath, int line);
 
-    void fileOpenRequested(const QString& filePath, const QString& str, const QString& ctxt);
+    void fileOpenRequested(const QString& filePath, const QString& str, const QString& ctxt, const bool setAsActive);
 
     //emitted when mainwindow is closed or another file is opened
     void fileClosed();
@@ -335,7 +377,7 @@ signals:
 
     Q_SCRIPTABLE void entryDisplayed();
     void signalNewEntryDisplayed(const DocPosition&);
-    void signalEntryWithMergeDisplayed(bool,const DocPosition&);
+    void signalEntryWithMergeDisplayed(bool, const DocPosition&);
     void signalFirstDisplayed(bool);
     void signalLastDisplayed(bool);
 
