@@ -31,13 +31,15 @@
 #include <QRunnable>
 
 #include <QString>
+#include <QMutex>
 #include <QSqlDatabase>
 class QSqlQuery;
 
 /**
  * Translation Memory classes. see initDb() function for the database scheme
  */
-namespace TM {
+namespace TM
+{
 
 #define TM_DATABASE_EXTENSION ".db"
 #define REMOTETM_DATABASE_EXTENSION ".remotedb"
@@ -54,17 +56,17 @@ QThreadPool* threadPool();
 #define TMTABSELECT  100
 #define UPDATE  80
 #define REMOVE  70
+#define REMOVEFILE  69
 #define INSERT  60
 #define SELECT  50
 #define BATCHSELECTFINISHED  49
 #define IMPORT 30
 #define EXPORT 25
+#define REMOVEMISSINGFILES    11
 #define SCAN    10
 #define SCANFINISHED 9
 
-
-struct TMConfig
-{
+struct TMConfig {
     QString markup;
     QString accel;
     QString sourceLangCode;
@@ -78,25 +80,29 @@ class OpenDBJob: public QObject, public QRunnable
 {
     Q_OBJECT
 public:
-    struct ConnectionParams
-    {
+    struct ConnectionParams {
         QString driver, host, db, user, passwd;
-        bool isFilled(){return !host.isEmpty() && !db.isEmpty() && !user.isEmpty();}
+        bool isFilled()
+        {
+            return !host.isEmpty() && !db.isEmpty() && !user.isEmpty();
+        }
     };
 
-    explicit OpenDBJob(const QString& dbName, DbType type=TM::Local, bool reconnect=false, const ConnectionParams& connParams=ConnectionParams());
+    explicit OpenDBJob(const QString& dbName, DbType type = TM::Local, bool reconnect = false, const ConnectionParams& connParams = ConnectionParams());
     ~OpenDBJob();
 
-    int priority()const{return OPENDB;}
-
-    struct DBStat
+    int priority() const
     {
-        int pairsCount,uniqueSourcesCount,uniqueTranslationsCount;
-        DBStat():pairsCount(0),uniqueSourcesCount(0),uniqueTranslationsCount(0){}
+        return OPENDB;
+    }
+
+    struct DBStat {
+        int pairsCount, uniqueSourcesCount, uniqueTranslationsCount;
+        DBStat(): pairsCount(0), uniqueSourcesCount(0), uniqueTranslationsCount(0) {}
     };
 
 protected:
-    void run ();
+    void run() override;
 
 signals:
     void done(OpenDBJob*);
@@ -124,14 +130,20 @@ public:
     explicit CloseDBJob(const QString& dbName);
     ~CloseDBJob();
 
-    int priority()const{return CLOSEDB;}
-    QString dbName(){return m_dbName;}
+    int priority() const
+    {
+        return CLOSEDB;
+    }
+    QString dbName()
+    {
+        return m_dbName;
+    }
 
 signals:
     void done(CloseDBJob*);
 
 protected:
-    void run ();
+    void run() override;
 
     QString m_dbName;
     //statistics?
@@ -151,13 +163,16 @@ public:
               const QString& dbName);
     ~SelectJob();
 
-    int priority()const{return SELECT;}
+    int priority() const
+    {
+        return SELECT;
+    }
 
 signals:
     void done(SelectJob*);
 
 protected:
-    void run ();
+    void run() override;
     //void aboutToBeDequeued(ThreadWeaver::WeaverInterface*); KDE5PORT
 
 private:
@@ -180,10 +195,52 @@ public:
     QString m_dbName;
 };
 
-enum {Enqueue=1};
-SelectJob* initSelectJob(Catalog*, DocPosition pos, QString db=QString(), int opt=Enqueue);
+enum {Enqueue = 1};
+SelectJob* initSelectJob(Catalog*, DocPosition pos, QString db = QString(), int opt = Enqueue);
 
 
+class RemoveMissingFilesJob: public QObject, public QRunnable
+{
+    Q_OBJECT
+public:
+    explicit RemoveMissingFilesJob(const QString& dbName);
+    ~RemoveMissingFilesJob();
+    int priority() const
+    {
+        return REMOVEMISSINGFILES;
+    }
+
+protected:
+    void run() override;
+
+    QString m_dbName;
+
+signals:
+    void done();
+};
+
+class RemoveFileJob: public QObject, public QRunnable
+{
+    Q_OBJECT
+public:
+    explicit RemoveFileJob(const QString& filePath, const QString& dbName, QObject *parent = nullptr);
+    ~RemoveFileJob();
+    int priority() const
+    {
+        return REMOVEFILE;
+    }
+
+protected:
+    void run() override;
+
+    QString m_filePath;
+    QString m_dbName;
+    QObject m_parent;
+
+signals:
+    void done();
+};
+
 
 class RemoveJob: public QObject, public QRunnable
 {
@@ -191,10 +248,13 @@ class RemoveJob: public QObject, public QRunnable
 public:
     explicit RemoveJob(const TMEntry& entry);
     ~RemoveJob();
-    int priority()const{return REMOVE;}
+    int priority() const
+    {
+        return REMOVE;
+    }
 
 protected:
-    void run();
+    void run() override;
 
     TMEntry m_entry;
 
@@ -223,12 +283,15 @@ public:
                        //const DocPosition&,//for back tracking
                        const QString& dbName);
 
-    ~UpdateJob(){}
+    ~UpdateJob() {}
 
-    int priority()const{return UPDATE;}
+    int priority() const
+    {
+        return UPDATE;
+    }
 
 protected:
-    void run ();
+    void run() override;
 
 private:
     QString m_filePath;
@@ -247,10 +310,13 @@ public:
     explicit ScanJob(const QString& filePath, const QString& dbName);
     ~ScanJob();
 
-    int priority()const{return SCAN;}
+    int priority() const
+    {
+        return SCAN;
+    }
 
 protected:
-    void run ();
+    void run() override;
 public:
     QString m_filePath;
 
@@ -264,19 +330,23 @@ public:
     QString m_dbName;
 };
 
-class ScanJobFeedingBack: public QObject, public ScanJob 
+class ScanJobFeedingBack: public QObject, public ScanJob
 {
     Q_OBJECT
 public:
     explicit ScanJobFeedingBack(const QString& filePath,
-                     const QString& dbName)
-    : QObject(), ScanJob(filePath, dbName)
+                                const QString& dbName)
+        : QObject(), ScanJob(filePath, dbName)
     {
         setAutoDelete(false);
     }
 
 protected:
-    void run (){ScanJob::run();emit done(this);}
+    void run() override
+    {
+        ScanJob::run();
+        emit done(this);
+    }
 
 signals:
     void done(ScanJobFeedingBack*);
@@ -291,15 +361,21 @@ public:
         : QObject(), QRunnable()
         , m_view(view)
     {}
-    ~BatchSelectFinishedJob(){};
+    ~BatchSelectFinishedJob() override {}
 
-    int priority()const{return BATCHSELECTFINISHED;}
+    int priority() const
+    {
+        return BATCHSELECTFINISHED;
+    }
 
 signals:
     void done();
 
 protected:
-    void run (){emit done();};
+    void run() override
+    {
+        emit done();
+    }
 public:
     QWidget* m_view;
 };
@@ -313,13 +389,16 @@ class IndexWordsJob: public QRunnable
 {
     Q_OBJECT
 public:
-    IndexWordsJob(QObject* parent=0);
+    IndexWordsJob(QObject* parent = nullptr);
     ~IndexWordsJob();
 
-    int priority()const{return 100;}
+    int priority() const
+    {
+        return 100;
+    }
 
 protected:
-    void run ();
+    void run();
 public:
     TMWordHash m_tmWordHash;
 
@@ -336,13 +415,16 @@ class ImportTmxJob: public QRunnable
 {
 public:
     explicit ImportTmxJob(const QString& url,
-                     const QString& dbName);
+                          const QString& dbName);
     ~ImportTmxJob();
 
-    int priority()const{return IMPORT;}
+    int priority() const
+    {
+        return IMPORT;
+    }
 
 protected:
-    void run ();
+    void run() override;
 public:
     QString m_filename;
 
@@ -358,13 +440,16 @@ class ExportTmxJob: public QRunnable
 {
 public:
     explicit ExportTmxJob(const QString& url,
-                     const QString& dbName);
+                          const QString& dbName);
     ~ExportTmxJob();
 
-    int priority()const{return IMPORT;}
+    int priority() const
+    {
+        return IMPORT;
+    }
 
 protected:
-    void run ();
+    void run() override;
 public:
     QString m_filename;
 
@@ -380,10 +465,13 @@ class ExecQueryJob: public QObject, public QRunnable
 {
     Q_OBJECT
 public:
-    explicit ExecQueryJob(const QString& queryString, const QString& dbName);
+    explicit ExecQueryJob(const QString& queryString, const QString& dbName, QMutex *dbOperation);
     ~ExecQueryJob();
 
-    int priority()const{return TMTABSELECT;}
+    int priority() const
+    {
+        return TMTABSELECT;
+    }
 
 
     QSqlQuery* query;
@@ -392,10 +480,11 @@ signals:
     void done(ExecQueryJob*);
 
 protected:
-    void run ();
+    void run() override;
 
     QString m_dbName;
     QString m_query;
+    QMutex* m_dbOperationMutex;
     //statistics?
 };
 
