@@ -8,7 +8,7 @@
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy 
+  by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.
 
   This program is distributed in the hope that it will be useful,
@@ -38,7 +38,8 @@ class QDropEvent;
 class QDragEnterEvent;
 
 #define TM_SHORTCUTS 10
-namespace TM {
+namespace TM
+{
 class TextBrowser;
 class SelectJob;
 
@@ -46,24 +47,29 @@ class TMView: public QDockWidget
 {
     Q_OBJECT
 public:
-    TMView(QWidget*,Catalog*,const QVector<QAction*>&);
-    ~TMView();
+    explicit TMView(QWidget*, Catalog*, const QVector<QAction*>&, const QVector<QAction*>&);
+    ~TMView() override;
 
-    void dragEnterEvent(QDragEnterEvent* event);
-    void dropEvent(QDropEvent*);
+    void dragEnterEvent(QDragEnterEvent* event) override;
+    void dropEvent(QDropEvent*) override;
 
-    QSize sizeHint() const{return QSize(300,100);}
+    QSize sizeHint() const override
+    {
+        return QSize(300, 100);
+    }
 signals:
 //     void textReplaceRequested(const QString&);
     void refreshRequested();
     void textInsertRequested(const QString&);
-    void fileOpenRequested(const QString& filePath, const QString& str, const QString& ctxt);
+    void fileOpenRequested(const QString& filePath, const QString& str, const QString& ctxt, const bool setAsActive);
 
 public slots:
-    void slotNewEntryDisplayed(const DocPosition& pos=DocPosition());
+    void slotNewEntryDisplayed();
+    void slotNewEntryDisplayed(const DocPosition& pos);
     void slotSuggestionsCame(SelectJob*);
 
     void slotUseSuggestion(int);
+    void slotRemoveSuggestion(int);
     void slotFileLoaded(const QString& url);
     void displayFromCache();
 
@@ -80,9 +86,11 @@ private slots:
 
     void initLater();
     void contextMenu(const QPoint & pos);
+    void removeEntry(const TMEntry & e);
 
 private:
-    bool event(QEvent *event);
+    bool event(QEvent *event) override;
+    void deleteFile(const TMEntry& e, const bool showPopUp);
 
 
 private:
@@ -91,7 +99,8 @@ private:
     DocPosition m_pos;
 
     SelectJob* m_currentSelectJob;
-    QVector<QAction*> m_actions;//need them to get shortcuts
+    QVector<QAction*> m_actions_insert;//need them to get insertion shortcuts
+    QVector<QAction*> m_actions_remove;//need them to get deletion shortcuts
     QList<TMEntry> m_entries;
     QMap<int, int> m_entryPositions;
 
@@ -110,11 +119,11 @@ class TextBrowser: public QTextBrowser
 {
     Q_OBJECT
 public:
-    TextBrowser(QWidget* parent):QTextBrowser(parent)
+    explicit TextBrowser(QWidget* parent): QTextBrowser(parent)
     {
         setContextMenuPolicy(Qt::CustomContextMenu);
     }
-    void mouseDoubleClickEvent(QMouseEvent* event);
+    void mouseDoubleClickEvent(QMouseEvent* event) override;
 signals:
     void textInsertRequested(const QString&);
 };
